=============
Installation
=============

You can install ``hepfile`` one of two different ways: using ``pip`` or ``flit``.

####
pip
####

***THIS IS NOT WORKING YET BUT IT WILL BE***::

    pip install hepfile

####
flit
####

``flit`` is used to do a local install if you have downloaded the source
code to your local machine. This is particularly useful if you are developing
or extending ``hepfile``.

First make sure you have `flit <https://flit.readthedocs.io/en/latest/>`_ installed. 
You will also need to have `autodoc <https://pypi.org/project/autodoc/>`_ installed for 
the documentation to also be locally generated. 

Once those are installed, clone the `hepfile <https://github.com/mattbellis/hepfile>`_ repository and go
into the ``hepfile`` directory. From there run the command::


    flit install




